.. contents::

Introduction
============

Policy package for cpskin


Tests
=====

This package is tested using Travis CI. The current status is :

.. image:: https://travis-ci.org/IMIO/cpskin.policy.png
    :target: http://travis-ci.org/IMIO/cpskin.policy
    
.. image:: https://coveralls.io/repos/github/IMIO/cpskin.policy/badge.svg?branch=master 
    :target: https://coveralls.io/github/IMIO/cpskin.policy?branch=master
